
# gender_predictor

## credits

- https://github.com/sholiday/genderPredictor
- https://github.com/clintval/gender-predictor
- https://stephenholiday.com/articles/2011/gender-prediction-with-python/index.html
